
RELEASE_VERSION='0.3.571007308'
BUILD_DATE='Thu Jun 23 08:31:28 UTC 2022'
BUILD_MACHINE_INFO='Linux runner-opyxurxq-project-28359933-concurrent-06wswn 5.4.181-99.354.amzn2.x86_64 #1 SMP Wed Mar 2 18:50:46 UTC 2022 x86_64 GNU/Linux'
GITLAB_CI_JOB_ID='2629554529'
GIT_COMMIT_SHA='8bc6a96a2ba71e0e7dad47caecc2e6d3844d43b4'
GIT_BRANCH='main'
